==> nodemc_alts-1.0.5.tgz: package/README.md <==
# nodemc_alts
![npm](https://img.shields.io/npm/v/nodemc_alts)
## Install

```
$ npm install nodemc_alts
```


## Usage

### Node Minecraft Protocol
NOTICE : you can still create a node mc protocol object using new nodealt();, but due to the additino of mineflayer support, it is advised that you use new nodealt.nodeprotocol();

Easymc
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.easymc(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
TheAltening
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.altening(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
FastAlts
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.fastalts(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```

### Mineflayer
Easymc
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.easymc(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
TheAltening
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.altening(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
FastAlts
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.fastalts(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```

==> nodemc_alts-1.0.6.tgz: package/README.md <==
# nodemc_alts
![npm](https://img.shields.io/npm/v/nodemc_alts)
## Install

```
$ npm install nodemc_alts
```


## Usage

### Node Minecraft Protocol
NOTICE : you can still create a node mc protocol object using new nodealt();, but due to the addition of mineflayer support, it is advised that you use new nodealt.nodeprotocol();

Easymc
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.easymc(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
TheAltening
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.altening(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
FastAlts
```js
var mc = require('minecraft-protocol');
const nodealt = require('nodemc_alts');
const alt = new nodealt.nodeprotocol();

var client = alt.fastalts(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```

### Mineflayer
Easymc
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.easymc(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
TheAltening
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.altening(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
FastAlts
```js
var flayer = require('mineflayer');
const nodealt = require('nodemc_alts');
const alt = new nodealt.mineflayer();

var client = alt.fastalts(TOKENHERE /* required */,SERVERIP HERE /* required */,PORT /* optional */);

client.on('connect', function() {
  console.log("connected pog");
});
//...
```
